@@ -1,9 +1,11 @@
 from .main import YEPCHAT
+from .main import AsyncYEPCHAT
 from .main import session
 
 __info__ = "Interact with YepChat, LLM provider"
 
 __all__ = [
     "YEPCHAT",
+    "AsyncYEPCHAT",
     "session",
 ]
